@@ -36,6 +36,7 @@ class Configuration(object):
     hash_upper = False
     deep = False
     ignore_rules={}
+    stop_on = {}
     proxy=''
     proxy_report_to=''
     text_to_find = []
@@ -362,7 +363,6 @@ class Configuration(object):
         else:
             Logger.pl('     {C}case insensitive search:{O} no{W}')
 
-
         if args.extensions != '':
             ext_list = args.extensions.split(",")
             for ex in ext_list:
@@ -382,7 +382,6 @@ class Configuration(object):
         if Configuration.out_file != '':
             Logger.pl('     {C}output file:{O} %s{W}' % Configuration.out_file)
 
-
         if args.filter_rules != '':
             ignore_list = args.filter_rules.split(",")
             for ignore_line in ignore_list:
@@ -419,6 +418,46 @@ class Configuration(object):
                         Configuration.ignore_rules[res] = []
                     Configuration.ignore_rules[res].append(False)
 
+        if args.stop_on != '':
+            stop_list = args.stop_on.split(",")
+            for stop_line in stop_list:
+                stop_line = stop_line.strip()
+                if ':' in stop_line:
+                    (i_result, i_size) = stop_line.split(":")
+                    size = 0
+                    res = 0
+                    try:
+                        res = int(i_result)
+                    except:
+                        Logger.pl(
+                            '{!} {R}error: could not convert {O}%s{R} from {O}%s{R} to an integer value {W}\r\n' % (
+                            i_result, stop_line))
+                        Configuration.exit_gracefully(0)
+
+                    try:
+                        size = int(i_size)
+                    except:
+                        Logger.pl(
+                            '{!} {R}error: could not convert {O}%s{R} from {O}%s{R} to an integer value {W}\r\n' % (
+                            i_size, stop_line))
+                        Configuration.exit_gracefully(0)
+
+                    if not res in Configuration.stop_on:
+                        Configuration.stop_on[res] = []
+                    Configuration.stop_on[res].append(size)
+
+                else:
+                    res = 0
+                    try:
+                        res = int(stop_line)
+                    except:
+                        Logger.pl(
+                            '{!} {R}error: could not convert {O}%s{R} to an integer value {W}\r\n' % (stop_line))
+                        Configuration.exit_gracefully(0)
+
+                    if not res in Configuration.stop_on:
+                        Configuration.stop_on[res] = []
+                    Configuration.stop_on[res].append(False)
 
         if Configuration.statsdb:
             try:
