@@ -138,17 +138,29 @@ class Getter:
             method = force_method.upper()
 
         if method == "POST":
-            return requests.post(url, verify=False, timeout=30, data={}, headers=headers, proxies=(proxy if proxy!=None else Getter.proxy))
+            return requests.post(url, verify=False, timeout=30, data={}, headers=headers,
+                                 allow_redirects=Configuration.forward_location,
+                                 proxies=(proxy if proxy is not None else Getter.proxy))
         elif method == "PUT":
-            return requests.put(url, verify=False, timeout=30, data={}, headers=headers, proxies=(proxy if proxy!=None else Getter.proxy))
+            return requests.put(url, verify=False, timeout=30, data={}, headers=headers,
+                                allow_redirects=Configuration.forward_location,
+                                proxies=(proxy if proxy is not None else Getter.proxy))
         elif method == "OPTIONS":
-            return requests.options(url, verify=False, timeout=30, headers=headers, proxies=(proxy if proxy!=None else Getter.proxy))
+            return requests.options(url, verify=False, timeout=30, headers=headers,
+                                    allow_redirects=Configuration.forward_location,
+                                    proxies=(proxy if proxy is not None else Getter.proxy))
         elif method == "HEAD":
-            return requests.head(url, verify=False, timeout=30, headers=headers, proxies=(proxy if proxy!=None else Getter.proxy))
+            return requests.head(url, verify=False, timeout=30, headers=headers,
+                                 allow_redirects=Configuration.forward_location,
+                                 proxies=(proxy if proxy is not None else Getter.proxy))
         elif method == "PATCH":
-            return requests.patch(url, verify=False, timeout=30, headers=headers, proxies=(proxy if proxy!=None else Getter.proxy))
+            return requests.patch(url, verify=False, timeout=30, headers=headers,
+                                  allow_redirects=Configuration.forward_location,
+                                  proxies=(proxy if proxy is not None else Getter.proxy))
         else:
-            return requests.get(url, verify=False, timeout=30, headers=headers, proxies=(proxy if proxy!=None else Getter.proxy))
+            return requests.get(url, verify=False, timeout=30, headers=headers,
+                                allow_redirects=Configuration.forward_location,
+                                proxies=(proxy if proxy is not None else Getter.proxy))
         
     @staticmethod
     def calc_not_fount(url):
@@ -365,6 +377,16 @@ class Getter:
 
     def chech_if_rise(self, url, status_code, size, method, directory_info, check_dir=True):
 
+        if status_code in Configuration.stop_on:
+            if False in Configuration.stop_on[status_code]:
+                Logger.pl('{!} {R}Stopping test: location %s with status code %s and size %s{W}' % (
+                    url, status_code, size))
+                Configuration.kill(1)
+            elif size in Configuration.stop_on[status_code]:
+                Logger.pl('{!} {R}Stopping test: location %s with status code %s and size %s{W}' % (
+                    url, status_code, size))
+                Configuration.kill(1)
+
         if status_code in Configuration.ignore_rules:
             if False in Configuration.ignore_rules[status_code]:
                 if Configuration.verbose > 0:
